@@ -15,8 +15,9 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.10',
  'BLDLIBRARY': '-L. -lpython3.10',
- 'BLDSHARED': 'gcc -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
-              '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g',
+ 'BLDSHARED': 'gcc -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    '
+              '-Wl,--build-id=sha1  -g  -Wl,-z,relro -Wl,--as-needed  '
+              '-Wl,-z,now    -Wl,--build-id=sha1  -g',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'armv7hl-redhat-linux-gnu',
@@ -62,12 +63,16 @@ build_time_vars = {'ABIFLAGS': '',
                             '-flto-partition=none -g -std=c99 -Wextra '
                             '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g',
+ 'CONFIGURE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    '
+                      '-Wl,--build-id=sha1  -g',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   '
+                             '-Wl,--build-id=sha1 '
+                             '-Wl,-dT,/builddir/build/BUILD/Python-3.10.4/.package_note-python3.10-3.10.4-1.fc36.arm.ld '
                              '-g  -fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g',
@@ -98,16 +103,17 @@ build_time_vars = {'ABIFLAGS': '',
                 '-march=armv7-a -mfpu=vfpv3-d16 -mtune=generic-armv7-a '
                 '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE -fPIC '
                 "-fwrapv ' 'LDFLAGS= -Wl,-z,relro -Wl,--as-needed  "
-                "-Wl,-z,now    -g ' 'CPPFLAGS='",
+                "-Wl,-z,now    -Wl,--build-id=sha1  -g ' 'CPPFLAGS=' "
+                "'PKG_CONFIG_PATH=:/usr/lib/pkgconfig:/usr/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.10.0/build/optimized/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.10.0/build/optimized/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.10.4/build/optimized/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.10.4/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.10.0/Include',
+             '-I/builddir/build/BUILD/Python-3.10.4/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib /usr/lib/python3.10 '
              '/usr/lib/python3.10/lib-dynload',
@@ -332,8 +338,10 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
  'HAVE_LINUX_CAN_J1939_H': 1,
@@ -357,8 +365,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 1,
- 'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
+ 'HAVE_MINIX_CONFIG_H': 0,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
  'HAVE_MKFIFOAT': 1,
@@ -423,6 +431,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -472,6 +481,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STAT_TV_NSEC2': 0,
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
+ 'HAVE_STDIO_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
  'HAVE_STRFTIME': 1,
@@ -495,6 +505,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -589,12 +600,14 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  -Wl,-z,relro '
-            '-Wl,--as-needed  -Wl,-z,now    -g',
+ 'LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -Wl,--build-id=sha1  '
+            '-g  -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    '
+            '-Wl,--build-id=sha1  -g',
  'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
-             '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g',
+ 'LDSHARED': 'gcc -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    '
+             '-Wl,--build-id=sha1  -g  -Wl,-z,relro -Wl,--as-needed  '
+             '-Wl,-z,now    -Wl,--build-id=sha1  -g',
  'LDVERSION': '3.10',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.10',
@@ -628,7 +641,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.10.0/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.10.4/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -734,6 +747,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-flto-partition=none -g -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden -O2 -flto=auto '
                              '-ffat-lto-objects -fexceptions -g '
@@ -746,9 +760,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE '
                              '-fPIC -fwrapv  -fprofile-use '
                              '-fprofile-correction '
-                             '-I/builddir/build/BUILD/Python-3.10.0/Include/internal '
+                             '-I/builddir/build/BUILD/Python-3.10.4/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.10.0/Include '
+                             '-I/builddir/build/BUILD/Python-3.10.4/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
@@ -778,7 +792,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fno-semantic-interposition -flto -fuse-linker-plugin '
                      '-ffat-lto-objects -flto-partition=none -g -std=c99 '
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
@@ -789,7 +803,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-mfpu=vfpv3-d16 -mtune=generic-armv7-a -mabi=aapcs-linux '
                      '-mfloat-abi=hard -D_GNU_SOURCE -fPIC -fwrapv  '
                      '-fprofile-use -fprofile-correction '
-                     '-I/builddir/build/BUILD/Python-3.10.0/Include/internal',
+                     '-I/builddir/build/BUILD/Python-3.10.4/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
@@ -818,7 +832,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-flto -fuse-linker-plugin -ffat-lto-objects '
                    '-flto-partition=none -g -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
                    '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
@@ -828,30 +842,43 @@ build_time_vars = {'ABIFLAGS': '',
                    '-mtune=generic-armv7-a -mabi=aapcs-linux -mfloat-abi=hard '
                    '-D_GNU_SOURCE -fPIC -fwrapv  -fprofile-use '
                    '-fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.10.0/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.10.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.10.0/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.10.4/Include -fPIC '
                    '-DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
-                    '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g '
-                    '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
-                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   -g  '
-                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
+ 'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    '
+                    '-Wl,--build-id=sha1  -g  -Wl,-z,relro -Wl,--as-needed  '
+                    '-Wl,-z,now    -Wl,--build-id=sha1  -g -Wl,-z,relro '
+                    '-Wl,--as-needed  -Wl,-z,now '
+                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   '
+                    '-Wl,--build-id=sha1 '
+                    '-Wl,-dT,/builddir/build/BUILD/Python-3.10.4/.package_note-python3.10-3.10.4-1.fc36.arm.ld '
+                    '-g  -fno-semantic-interposition -flto -fuse-linker-plugin '
                     '-ffat-lto-objects -flto-partition=none -g -Wl,-z,relro '
                     '-Wl,--as-needed  -Wl,-z,now '
-                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   -g',
+                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   '
+                    '-Wl,--build-id=sha1 '
+                    '-Wl,-dT,/builddir/build/BUILD/Python-3.10.4/.package_note-python3.10-3.10.4-1.fc36.arm.ld '
+                    '-g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.10.0/Include',
+                '-I/builddir/build/BUILD/Python-3.10.4/Include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  -Wl,-z,relro '
-               '-Wl,--as-needed  -Wl,-z,now    -g',
+ 'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    '
+               '-Wl,--build-id=sha1  -g  -Wl,-z,relro -Wl,--as-needed  '
+               '-Wl,-z,now    -Wl,--build-id=sha1  -g',
  'PY_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
-                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   -g  '
-                      '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                      '-ffat-lto-objects -flto-partition=none -g -Wl,-z,relro '
-                      '-Wl,--as-needed  -Wl,-z,now '
-                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   -g',
+                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   '
+                      '-Wl,--build-id=sha1 '
+                      '-Wl,-dT,/builddir/build/BUILD/Python-3.10.4/.package_note-python3.10-3.10.4-1.fc36.arm.ld '
+                      '-g  -fno-semantic-interposition -flto '
+                      '-fuse-linker-plugin -ffat-lto-objects '
+                      '-flto-partition=none -g -Wl,-z,relro -Wl,--as-needed  '
+                      '-Wl,-z,now '
+                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld   '
+                      '-Wl,--build-id=sha1 '
+                      '-Wl,-dT,/builddir/build/BUILD/Python-3.10.4/.package_note-python3.10-3.10.4-1.fc36.arm.ld '
+                      '-g',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
@@ -885,7 +912,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-fuse-linker-plugin -ffat-lto-objects '
                         '-flto-partition=none -g -std=c99 -Wextra '
                         '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
@@ -896,9 +923,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-mfpu=vfpv3-d16 -mtune=generic-armv7-a '
                         '-mabi=aapcs-linux -mfloat-abi=hard -D_GNU_SOURCE '
                         '-fPIC -fwrapv  -fprofile-use -fprofile-correction '
-                        '-I/builddir/build/BUILD/Python-3.10.0/Include/internal '
+                        '-I/builddir/build/BUILD/Python-3.10.4/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.10.0/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.10.4/Include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -907,10 +934,9 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.0/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.4/build/optimized',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
@@ -937,7 +963,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-310-arm-linux-gnueabihf',
  'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.10.0/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.10.4/Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 0,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -947,28 +973,29 @@ build_time_vars = {'ABIFLAGS': '',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
+ 'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.0/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.4/build/optimized '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.0/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.10.4/build/optimized '
                './python '
-               '/builddir/build/BUILD/Python-3.10.0/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.10.4/Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.10.0/Tools/scripts/update_file.py',
+ 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.10.4/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.10',
- 'VPATH': '/builddir/build/BUILD/Python-3.10.0',
+ 'VPATH': '/builddir/build/BUILD/Python-3.10.4',
  'WHEEL_PKG_DIR': '/usr/share/python-wheels',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
@@ -982,9 +1009,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.10.0/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.10.0',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.10.4/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.10.4',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.10.0'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.10.4'}
